#!/usr/bin/python3
# -*- coding: utf-8 -*-
# Author: Tuncay ÇOLAK <tuncay.colak@tubitak.gov.tr>

import gi

gi.require_version('Gtk', '3.0')
from gi.repository import Gtk
import sqlite3


class LiderNotifyView(Gtk.Window):

    def __init__(self):
        Gtk.Window.__init__(self, title="Liderahenk Bildirimler")

        self.connection = None
        self.notify_count = 0
        self.icon_file_path = "/usr/share/liderahenk-notify/notify.svg"
        self.db_path = "/etc/ahenk/ahenk.db"
        self.notify_list = []

        self.set_border_width(10)
        self.set_icon_from_file(self.icon_file_path)

        ## get notifications from ahenk.db

        db_connect, p_err = self.db_connect()
        print(db_connect)
        if db_connect is True:
            notifications = self.select("SELECT * FROM notify ORDER BY id DESC")
            self.notify_count = self.select("select count (*) from notify")

            self.notify_count = self.notify_count[0][0]
            # for i in self.notify_count:
            #     print(i[0])

            if len(notifications) != 0:
                for row in notifications:
                    # print ("Id: ",row[0])
                    # print ("Send Time: ",row[1])
                    # print ("Content: ",row[2])
                    # print ("Duration: ",row[3])
                    # print ("Status: ",row[4])
                    # print ("\n")
                    content = row[2]
                    content = content[0:50].split("\n")[0].rstrip()+"..."
                    line = (row[0], row[1], content)
                    self.notify_list.append(line)


        self.grid = Gtk.Grid()
        self.grid.set_column_homogeneous(True)
        self.grid.set_row_homogeneous(True)
        self.add(self.grid)

        # Creating the ListStore model
        self.notify_liststore = Gtk.ListStore(int, str, str)
        for notify_ref in self.notify_list:
            self.notify_liststore.append(list(notify_ref))
        self.current_filter_notify = None

        # Creating the filter, feeding it with the liststore model
        self.notify_filter = self.notify_liststore.filter_new()
        # setting the filter function, note that we're not using the
        self.notify_filter.set_visible_func(self.notify_filter_func)

        # creating the treeview, making it use the filter as a model, and adding the columns
        self.treeview = Gtk.TreeView.new_with_model(self.notify_filter)
        for i, column_title in enumerate(["Bildirim ID", "Gönderilme Tarihi", "Bildirim"]):
            renderer = Gtk.CellRendererText()
            column = Gtk.TreeViewColumn(column_title, renderer, text=i)
            self.treeview.append_column(column)

        ## creating Buttons
        self.button_about = Gtk.Button.new_with_label("Hakkında")
        self.button_open = Gtk.Button.new_with_label("Aç")
        if self.notify_count == 0:
            self.button_open.set_sensitive(False)
        else:
            self.button_open.set_sensitive(True)


        self.label_notify_count = Gtk.Label("12")
        self.label_notify = Gtk.Label("Toplam Bildirim Sayısı: ")

        ## Assigning action to buttons
        self.button_about.connect("clicked", self.on_about_clicked)
        self.button_open.connect("clicked", self.on_selection)

        ## creating Search entry
        self._search_entry = Gtk.SearchEntry(max_width_chars=2)
        self._search_entry.connect("search-changed", self.on_search_changed)
        self._search_entry.show()

        # setting up the layout, putting the treeview in a scrollwindow, and the buttons in a row
        self.scrollable_treelist = Gtk.ScrolledWindow()
        self.scrollable_treelist.set_vexpand(True)
        self.grid.attach(self.scrollable_treelist, 0, 0, 8, 15)
        self.grid.attach_next_to(self.button_about, self.scrollable_treelist, Gtk.PositionType.BOTTOM, 1, 1)
        # self.grid.attach_next_to(self.button_open, self.button_about, Gtk.PositionType.RIGHT, 1, 1)
        self.grid.attach(self.button_open, 7, 15,  1, 1)
        # self.grid.attach_next_to(self._search_entry, self.scrollable_treelist, Gtk.PositionType.TOP, 2, 1)
        self.scrollable_treelist.add(self.treeview)
        self.show_all()

        if db_connect is False:
            self.show_error("Liderahenk bildirim veritabanına erişilemedi!\n\n{0}".format(p_err))

    def on_selection(self, widget):
        try:
            self.selection = self.treeview.get_selection()
            self.selection.set_mode(Gtk.SelectionMode.SINGLE)
            (model, iter) = self.selection.get_selected()
            id = model[iter][0]
            # print(id)
            sql = "SELECT * FROM notify WHERE id=\"{0}\"".format(id)
            content = self.select(sql)
            for row in content:
                # print(row)
                self.show_notify(row[1], row[2])

        except Exception as e:
            print('Bildirim bulunamadı: {0}'.format(str(e)))
            self.show_notify("Bildirim bulunamadı.")

    def db_connect(self):
        try:
            self.connection = sqlite3.connect(self.db_path, check_same_thread=False)
            self.cursor = self.connection.cursor()
            print("Successfully connection database")
            return True, "Successfully connection database"
        except Exception as e:
            print('Database connection error: {0}'.format(str(e)))
            return False, "Database connection error: {0}".format(str(e))

    def select(self, sql):
        self.cursor.execute(sql)
        self.connection.commit()
        notifications = self.cursor.fetchall()
        return notifications

    def notify_filter_func(self, model, iter, data):
        """Tests if the notify in the row is the one in the filter"""
        if self.current_filter_notify is None or self.current_filter_notify == "None":
            return True
        else:
            return model[iter][0] == self.current_filter_notify

    def on_selection_button_clicked(self, widget):
        """Called on any of the button clicks"""
        # we set the current notify filter to the button's label
        self.current_filter_notify = widget.get_label()
        print("%s notify selected!" % self.current_filter_notify)
        # we update the filter, which updates in turn the view
        self.notify_filter.refilter()

    def on_about_clicked(self, widget):
        about = Gtk.AboutDialog()
        about.set_name('Hakkında')
        about.set_resizable(True)
        about.set_icon_from_file(self.icon_file_path)
        about.set_program_name("Liderahenk Bildirim")
        about.set_version("1.0")
        # about.set_authors("\n")
        # about.set_copyright("pardus")
        about.set_comments("Liderahenk MYS tarafından gönderilen bildirimleri\n"
                           "açmak için kullanılır. Bildirimler gönderilme tarihine göre\n"
                           "seçilerek görüntülenir.\n\n"
                           "Toplam Bildirim Sayısı: {0}".format(self.notify_count))
        about.set_website("http://liderahenk.org/")
        about.run()
        about.destroy()

    def show_notify(self, send_time, content):
        dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.INFO,
                                   Gtk.ButtonsType.OK,
                                   "Gönderilme Zamanı: {send_time}\n\n{content}".format(send_time=send_time,
                                                                                        content=content))
        dialog.set_title("Bildirim")
        dialog.set_default_size(300, 200)
        dialog.set_icon_from_file(self.icon_file_path)
        dialog.run()
        print("INFO dialog closed")
        dialog.destroy()

    def show_error(self, content):
        dialog = Gtk.MessageDialog(self, 0, Gtk.MessageType.ERROR,
                                   Gtk.ButtonsType.OK,
                                   "{content}".format(content=content))

        dialog.set_title("UYARI")
        dialog.set_default_size(300, 200)
        dialog.set_icon_from_file(self.icon_file_path)
        dialog.run()
        print("INFO dialog closed")
        dialog.destroy()

    def on_search_changed(self, widget):
        self.current_filter_notify = widget.get_text()
        print("selected id {0}".format(self.current_filter_notify))
        # we update the filter, which updates in turn the view
        self.notify_filter.refilter()


win = LiderNotifyView()
win.connect("destroy", Gtk.main_quit)
# win.show_all()
Gtk.main()
